@@ -1,5 +1,7 @@
 """
-simple Git module, where needed via powershell
+Simple Git module, where needed via powershell
+
+Some of the functions are based on the gitpython module
 """
 import subprocess
 from pathlib import Path
@@ -8,8 +10,18 @@ from typing import List, Optional, Union
 from loguru import logger as log
 from packaging.version import parse
 
+from github import Github
+import cachetools.func
+import os
 
-def _run_git(
+
+# Token with no permissions
+PAT_NO_ACCESS = "github_pat" + "_11AAHPVFQ0IwtAmfc3cD5Z" + "_xOVII22ErRzzZ7xwwxRcNotUu4krMMbjinQcsMxjnWkYFBIDRWFlZMaHSqq"
+PAT = os.environ.get("GITHUB_TOKEN") or PAT_NO_ACCESS
+GH_CLIENT = Github(PAT)
+
+
+def _run_local_git(
     cmd: List[str],
     repo: Optional[Union[Path, str]] = None,
     expect_stderr=False,
@@ -28,7 +40,7 @@ def _run_git(
         return None
     except subprocess.CalledProcessError as e:  # pragma: no cover
         # add some logging for github actions
-        log.error("Exception on process, rc=", e.returncode, "output=", e.output.decode("utf-8"), "\nstderr=", e.stderr.decode("utf-8"))
+        log.error(f"{str(e)} : { e.stderr.decode('utf-8')}")
         return None
     if result.stderr and result.stderr != b"":
         stderr = result.stderr.decode("utf-8")
@@ -45,25 +57,21 @@ def _run_git(
     return result
 
 
-def clone(remote_repo: str, path: Path, shallow=False, tag: Optional[str] = None) -> bool:
+def clone(remote_repo: str, path: Path, shallow: bool = False, tag: Optional[str] = None) -> bool:
     """git clone [--depth 1] [--branch <tag_name>] <remote> <directory>"""
     cmd = ["git", "clone"]
     if shallow:
         cmd += ["--depth", "1"]
     if tag in ("latest", "master"):
         tag = None
-    cmd += (
-        [remote_repo, "--branch", tag, str(path)]
-        if tag
-        else [remote_repo, str(path)]
-    )
-    if result := _run_git(cmd, expect_stderr=True, capture_output=False):
+    cmd += [remote_repo, "--branch", tag, str(path)] if tag else [remote_repo, str(path)]
+    if result := _run_local_git(cmd, expect_stderr=True, capture_output=False):
         return result.returncode == 0
     else:
         return False
 
 
-def get_tag(repo: Optional[Union[str, Path]] = None, abbreviate: bool = True) -> Union[str, None]:
+def get_local_tag(repo: Optional[Union[str, Path]] = None, abbreviate: bool = True) -> Union[str, None]:
     """
     get the most recent git version tag of a local repo
     repo Path should be in the form of : repo = "./repo/micropython"
@@ -75,34 +83,31 @@ def get_tag(repo: Optional[Union[str, Path]] = None, abbreviate: bool = True) ->
     elif isinstance(repo, str):
         repo = Path(repo)
 
-    result = _run_git(["git", "describe"], repo=repo.as_posix(), expect_stderr=True)
+    result = _run_local_git(["git", "describe"], repo=repo.as_posix(), expect_stderr=True)
     if not result:
         return None
     tag: str = result.stdout.decode("utf-8")
     tag = tag.replace("\r", "").replace("\n", "")
     if abbreviate and "-" in tag:
-        if result := _run_git(
+        if result := _run_local_git(
             ["git", "status", "--branch"],
             repo=repo.as_posix(),
             expect_stderr=True,
         ):
             lines = result.stdout.decode("utf-8").replace("\r", "").split("\n")
-            if lines[0].startswith("On branch"):
-                if lines[0].endswith("master"):
-                    tag = "latest"
-                elif lines[0].endswith("fix_lib_documentation"):
-                    tag = "fix_lib_documentation"
+            if lines[0].startswith("On branch") and lines[0].endswith("master"):
+                tag = "latest"
     return tag
 
 
-def get_tags(repo: Optional[Path] = None, minver: Optional[str] = None) -> List[str]:
+def get_local_tags(repo: Optional[Path] = None, minver: Optional[str] = None) -> List[str]:
     """
     get list of tag of a local repo
     """
     if not repo:
         repo = Path(".")
 
-    result = _run_git(["git", "tag", "-l"], repo=repo.as_posix(), expect_stderr=True)
+    result = _run_local_git(["git", "tag", "-l"], repo=repo.as_posix(), expect_stderr=True)
     if not result or result.returncode != 0:
         return []
     tags = result.stdout.decode("utf-8").replace("\r", "").split("\n")
@@ -112,17 +117,32 @@ def get_tags(repo: Optional[Path] = None, minver: Optional[str] = None) -> List[
     return sorted(tags)
 
 
+@cachetools.func.ttl_cache(maxsize=16, ttl=60)  # 60 seconds
+def get_tags(repo: str, minver: Optional[str] = None) -> List[str]:
+    """
+    Get list of tag of a repote github repo
+    """
+    if not repo or not isinstance(repo, str) or "/" not in repo: # type: ignore
+        return []
+    gh_repo = GH_CLIENT.get_repo(repo)
+    tags = [tag.name for tag in gh_repo.get_tags()]
+    if minver:
+        tags = [tag for tag in tags if parse(tag) >= parse(minver)]
+    return sorted(tags)
+
+
 def checkout_tag(tag: str, repo: Optional[Union[str, Path]] = None) -> bool:
     """
     checkout a specific git tag
     """
     cmd = ["git", "checkout", "tags/" + tag, "--detach", "--quiet", "--force"]
-    result = _run_git(cmd, repo=repo, expect_stderr=True, capture_output=True)
+    result = _run_local_git(cmd, repo=repo, expect_stderr=True, capture_output=True)
     if not result:
         return False
     # actually a good result
-    log.debug(result.stderr.decode("utf-8"))
-    log.debug(result.stdout.decode("utf-8"))
+    msg = {result.stdout.decode("utf-8")}
+    if msg != {""}:
+        log.warning(f"git message: {msg}")
     return True
 
 
@@ -135,7 +155,7 @@ def synch_submodules(repo: Optional[Union[Path, str]] = None) -> bool:
         ["git", "submodule", "update", "--quiet"],
     ]
     for cmd in cmds:
-        if result := _run_git(cmd, repo=repo, expect_stderr=True):
+        if result := _run_local_git(cmd, repo=repo, expect_stderr=True):
             # actually a good result
             log.debug(result.stderr.decode("utf-8"))
         else:
@@ -148,7 +168,7 @@ def checkout_commit(commit_hash: str, repo: Optional[Union[Path, str]] = None) -
     Checkout a specific commit
     """
     cmd = ["git", "checkout", commit_hash, "--quiet", "--force"]
-    result = _run_git(cmd, repo=repo, expect_stderr=True)
+    result = _run_local_git(cmd, repo=repo, expect_stderr=True)
     if not result:
         return False
     # actually a good result
@@ -166,7 +186,7 @@ def switch_tag(tag: str, repo: Optional[Union[Path, str]] = None) -> bool:
     """
 
     cmd = ["git", "switch", "--detach", tag, "--quiet", "--force"]
-    result = _run_git(cmd, repo=repo, expect_stderr=True)
+    result = _run_local_git(cmd, repo=repo, expect_stderr=True)
     if not result:
         return False
     # actually a good result
@@ -183,7 +203,7 @@ def switch_branch(branch: str, repo: Optional[Union[Path, str]] = None) -> bool:
     returns None
     """
     cmd = ["git", "switch", branch, "--quiet", "--force"]
-    result = _run_git(cmd, repo=repo, expect_stderr=True)
+    result = _run_local_git(cmd, repo=repo, expect_stderr=True)
     if not result:
         return False
     # actually a good result
@@ -203,11 +223,11 @@ def fetch(repo: Union[Path, str]) -> bool:
         raise NotADirectoryError
 
     cmd = ["git", "fetch", "--all", "--tags", "--quiet"]
-    result = _run_git(cmd, repo=repo, echo_output=False)
+    result = _run_local_git(cmd, repo=repo, echo_output=False)
     return result.returncode == 0 if result else False
 
 
-def pull(repo: Union[Path, str], branch="main") -> bool:
+def pull(repo: Union[Path, str], branch: str = "main") -> bool:
     """
     pull a repo origin into main
     repo should be in the form of : path/.git
@@ -219,14 +239,37 @@ def pull(repo: Union[Path, str], branch="main") -> bool:
     repo = Path(repo)
     # first checkout HEAD
     cmd = ["git", "checkout", branch, "--quiet", "--force"]
-    result = _run_git(cmd, repo=repo, expect_stderr=True)
+    result = _run_local_git(cmd, repo=repo, expect_stderr=True)
     if not result:
         log.error("error during git checkout main", result)
         return False
 
     cmd = ["git", "pull", "origin", branch, "--quiet", "--autostash"]
-    result = _run_git(cmd, repo=repo, expect_stderr=True)
+    result = _run_local_git(cmd, repo=repo, expect_stderr=True)
     if not result:
         log.error("error durign pull", result)
         return False
     return result.returncode == 0
+
+
+def get_git_describe(folder: Optional[str] = None):
+    """ "based on MicroPython makeversionhdr
+    returns : current git tag, commits ,commit hash : "v1.19.1-841-g3446"
+    """
+    # Note: git describe doesn't work if no tag is available
+    try:
+        git_describe = subprocess.check_output(
+            ["git", "describe", "--tags", "--dirty", "--always", "--match", "v[1-9].*"],
+            stderr=subprocess.STDOUT,
+            universal_newlines=True,
+            cwd=folder,
+        ).strip()
+    except subprocess.CalledProcessError as er:
+        if er.returncode == 128:
+            # git exit code of 128 means no repository found
+            return None
+        git_describe = ""
+    except OSError:
+        return None
+    # format
+    return git_describe
