@@ -34,11 +34,11 @@ from .cli import stubber_cli
 @click.option("--black/--no-black", "-b/-nb", default=True, help="Run black", show_default=True)
 @click.pass_context
 def cli_docstubs(
-    ctx,
+    ctx: click.Context,
     path: str = CONFIG.repo_path.as_posix(),
     target: str = CONFIG.stub_path.as_posix(),
     black: bool = True,
-    basename="micropython",
+    basename: str = "micropython",
 ):
     """
     Build stubs from documentation.
@@ -54,19 +54,17 @@ def cli_docstubs(
         rst_path = Path(path) / "docs" / "library"
     else:
         rst_path = Path(path)  # or specify full path
-    v_tag = git.get_tag(rst_path.as_posix())
+    v_tag = git.get_local_tag(rst_path.as_posix())
     if not v_tag:
         # if we can't find a tag , bail
         raise ValueError("No valid Tag found")
     v_tag = utils.clean_version(v_tag, flat=True, drop_v=False)
-    release = git.get_tag(rst_path.as_posix(), abbreviate=False) or ""
+    release = git.get_local_tag(rst_path.as_posix(), abbreviate=False) or ""
 
     dst_path = Path(target) / f"{basename}-{v_tag}-docstubs"
 
-    # get verbose from the parent context
-    verbose = ctx.obj["verbose"] != 0
     log.info(f"Get docstubs for MicroPython {utils.clean_version(v_tag, drop_v=False)}")
-    generate_from_rst(rst_path, dst_path, v_tag, release=release, verbose=verbose, suffix=".pyi")
+    generate_from_rst(rst_path, dst_path, v_tag, release=release, suffix=".pyi")
 
     # no need to generate .pyi in post processing
     log.info("::group:: start post processing of retrieved stubs")
